@@ -15,7 +15,7 @@
 #   along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
-#   Copyright (C) 2004-2012   Teng Wei Hua <wadedang@gmail.com>, Xavier de Blas <xaviblas@gmail.com> 
+#   Copyright (C) 2004-2014   Teng Wei Hua <wadedang@gmail.com>, Xavier de Blas <xaviblas@gmail.com> 
 # 
 # encoding=utf-8
 #
@@ -49,23 +49,23 @@ record_time = int(sys.argv[3])*1000		#from s to ms
 minRange = int(sys.argv[4])			#all is stored, but only display when vertical range is >= minRange
 isJump = sys.argv[5]
 mass = float(sys.argv[6])
-smoothingOneEC = float(sys.argv[7])
-smoothingOneC = float(sys.argv[8])
-eccon = sys.argv[9]				#contraction "ec" or "c"
-analysisOptions = sys.argv[10]			#["p","none"]: propulsive or none
-heightHigherCondition = int(sys.argv[11])
-heightLowerCondition = int(sys.argv[12])
-meanSpeedHigherCondition = float(sys.argv[13])
-meanSpeedLowerCondition = float(sys.argv[14])
-maxSpeedHigherCondition = float(sys.argv[15])
-maxSpeedLowerCondition = float(sys.argv[16])
-powerHigherCondition = int(sys.argv[17])
-powerLowerCondition = int(sys.argv[18])
-peakPowerHigherCondition = int(sys.argv[19])
-peakPowerLowerCondition = int(sys.argv[20])
-mainVariable = sys.argv[21]
-inverted = sys.argv[22]
-w_serial_port = sys.argv[23]
+smoothingOneEC = .6 #float(sys.argv[7])
+smoothingOneC = float(sys.argv[7])
+eccon = sys.argv[8]				#contraction "ec" or "c"
+analysisOptions = sys.argv[9]			#["p","none"]: propulsive or none
+heightHigherCondition = int(sys.argv[10])
+heightLowerCondition = int(sys.argv[11])
+meanSpeedHigherCondition = float(sys.argv[12])
+meanSpeedLowerCondition = float(sys.argv[13])
+maxSpeedHigherCondition = float(sys.argv[14])
+maxSpeedLowerCondition = float(sys.argv[15])
+powerHigherCondition = int(sys.argv[16])
+powerLowerCondition = int(sys.argv[17])
+peakPowerHigherCondition = int(sys.argv[18])
+peakPowerLowerCondition = int(sys.argv[19])
+mainVariable = sys.argv[20]
+inverted = sys.argv[21]
+w_serial_port = sys.argv[22]
 
 delete_initial_time = 20			#delete first records because there's encoder bug
 #w_baudrate = 9600                           # Setting the baudrate of Chronopic(9600)
@@ -197,7 +197,8 @@ def calculate_all_in_r(temp, top_values, bottom_values, direction_now,
 			if bcrossLen == 0:
 				x_ini = 0
 			if bcrossLen == 1:
-				x_ini = bcross	#if bcross has only one item, then this fails: 'bcross[0]'. Just do 'bcross'
+				if bcross < maxSpeedT:
+					x_ini = bcross	#if bcross has only one item, then this fails: 'bcross[0]'. Just do 'bcross'
 			else:
 				x_ini = bcross[0]	#not 1, we are in python now
 				for i in bcross:
@@ -249,12 +250,12 @@ def calculate_all_in_r(temp, top_values, bottom_values, direction_now,
 			myR.run('accel$y <- accel$y[1:end]')
 
 		
-		print("new curve")
-		print(start+x_ini)
-		myspeedy=myR.get('speed$y')
-		print(myspeedy)
-
-
+#		print("new curve")
+#		print(start+x_ini)
+#		myspeedy=myR.get('speed$y')
+#		print(myspeedy)
+#
+#
 
 		myR.run('accel$y <- accel$y * 1000') #input data is in mm, conversion to m
 #		if isJump == "True":
@@ -348,19 +349,19 @@ def calculate_all_in_r(temp, top_values, bottom_values, direction_now,
 
 				#position it at 40+112+4 pixels vert: 156
 				#vertical_height: 600 -4 (lower sep) - 156 : 440
-				if mainVariable == "meanSpeed":
+				if mainVariable == "Mean Speed":
 					update_graph("Mean Speed (m/s)", meanSpeedList, 
 							meanSpeedLowerCondition, meanSpeedHigherCondition, hasRightMargin,
 							graphsWidth, 440, (222,222,222), 4, 156, True)
-				elif mainVariable == "maxSpeed":
+				elif mainVariable == "Max Speed":
 					update_graph("Max Speed (m/s)", maxSpeedList, 
 							maxSpeedLowerCondition, maxSpeedHigherCondition, hasRightMargin,
 							graphsWidth, 440, (222,222,222), 4, 156, True)
-				elif mainVariable == "meanPower":
+				elif mainVariable == "Mean Power":
 					update_graph("Mean Power (W)", meanPowerList, 
 							powerLowerCondition, powerHigherCondition, hasRightMargin,
 							graphsWidth, 440, (222,222,222), 4, 156, False)
-				else: #mainVariable == "peakPower"
+				else: #mainVariable == "Peak Power"
 					update_graph("Peak Power (W)", peakPowerList, 
 							peakPowerLowerCondition, peakPowerHigherCondition, hasRightMargin,
 							graphsWidth, 440, (222,222,222), 4, 156, False)
