@@ -68,61 +68,6 @@ public class EncoderParams
 	{
 	}
 
-	/*
-	//to encoder capture
-	//RunEncoderCapturePython: pyserial_pyper.py and pyserial_pyper_windows.py . This will be deprecated soon 
-	public EncoderParams(int time, int minHeight, int exercisePercentBodyWeight, string mass, 
-			string smoothCon, string eccon, string analysisOptions,
-			double heightHigherCondition, double heightLowerCondition, 
-			double meanSpeedHigherCondition, double meanSpeedLowerCondition, 
-			double maxSpeedHigherCondition, double maxSpeedLowerCondition, 
-			int powerHigherCondition, int powerLowerCondition, 
-			int peakPowerHigherCondition, int peakPowerLowerCondition,
-			string mainVariable//, bool inverted)
-		)
-	{
-		this.time = time;
-		this.minHeight = minHeight;
-		this.exercisePercentBodyWeight = exercisePercentBodyWeight;
-		this.mass = mass;
-		this.smoothCon = smoothCon;
-		this.eccon = eccon;
-		this.analysisOptions = analysisOptions;
-		this.heightHigherCondition = heightHigherCondition;
-		this.heightLowerCondition = heightLowerCondition;
-		this.meanSpeedHigherCondition = meanSpeedHigherCondition;
-		this.meanSpeedLowerCondition = meanSpeedLowerCondition;
-		this.maxSpeedHigherCondition = maxSpeedHigherCondition;
-		this.maxSpeedLowerCondition = maxSpeedLowerCondition;
-		this.powerHigherCondition = powerHigherCondition;
-		this.powerLowerCondition = powerLowerCondition;
-		this.peakPowerHigherCondition = peakPowerHigherCondition;
-		this.peakPowerLowerCondition = peakPowerLowerCondition;
-		this.mainVariable = mainVariable;
-		//this.inverted = inverted;
-	}
-
-	//to encoder capture
-	//RunEncoderCapturePython: pyserial_pyper.py and pyserial_pyper_windows.py . This will be deprecated soon 
-	public string ToString1 () 
-	{
-		string analysisOptionsPrint = analysisOptions;
-		if(analysisOptionsPrint == "")
-			analysisOptionsPrint = "none";
-
-		return time.ToString() + " " + minHeight.ToString() + " " + exercisePercentBodyWeight.ToString() + 
-			" " + mass.ToString() + " " + smoothCon + " " + eccon + " " + analysisOptionsPrint +
-			" " + heightHigherCondition.ToString() +	" " + heightLowerCondition.ToString() +
-			" " + Util.ConvertToPoint(meanSpeedHigherCondition.ToString()) + 	
-			" " + Util.ConvertToPoint(meanSpeedLowerCondition.ToString()) +
-			" " + Util.ConvertToPoint(maxSpeedHigherCondition.ToString()) + 	
-			" " + Util.ConvertToPoint(maxSpeedLowerCondition.ToString()) +
-			" " + powerHigherCondition.ToString() + 	" " + powerLowerCondition.ToString() +
-			" " + peakPowerHigherCondition.ToString() + 	" " + peakPowerLowerCondition.ToString() +
-			" " + mainVariable //+ " " + Util.BoolToInt(inverted).ToString();
-		;
-	}
-	*/
 	
 	//to graph.R	
 	public EncoderParams(int minHeight, int exercisePercentBodyWeight, string massBody, string massExtra, 
@@ -316,15 +261,28 @@ public class EncoderCurve
 		this.PP_PPT = PP_PPT;	//PeakPower / PeakPowerTime
 	}
 
-	public string ToCSV() {
-		string sep = ";";
-		return 
+	public string ToCSV(string decimalSeparator) {
+		//latin:	2,3 ; 2,5
+		//non-latin:	2.3 , 2.5
+
+		string sep = ":::";
+		string str = 
 			N + sep + Series + sep + Exercise + sep + 
 			ExtraWeight + sep + DisplacedWeight + sep + 
 			Start + sep + Duration + sep + Height + sep + 
 			MeanSpeed + sep + MaxSpeed + sep + MaxSpeedT + sep + 
 			MeanPower + sep + PeakPower + sep + PeakPowerT + sep + 
 			PP_PPT;
+		
+		if(decimalSeparator == "COMMA")
+			str = Util.ConvertToComma(str);
+		else
+			str = Util.ConvertToPoint(str);
+			
+		if(decimalSeparator == "COMMA")
+			return Util.ChangeChars(str, ":::", ";");
+		else
+			return Util.ChangeChars(str, ":::", ",");
 	}
 	
 	~EncoderCurve() {}
@@ -463,9 +421,12 @@ public class EncoderNeuromuscularData
 		this.cl_p_max 	= Convert.ToDouble(cells[16]);
 	}
 
-	public string ToCSV() {
-		string sep = ";";
-		return 
+	public string ToCSV(string decimalSeparator) {
+		//latin:	2,3 ; 2,5
+		//non-latin:	2.3 , 2.5
+
+		string sep = ":::";
+		string str = 
 			n + sep + e1_range.ToString() + sep + 
 			e1_t.ToString() + sep + e1_fmax.ToString() + sep + 
 			e1_rfd_avg.ToString() + sep + e1_i.ToString() + sep + 
@@ -474,6 +435,16 @@ public class EncoderNeuromuscularData
 			cl_f_avg.ToString() + sep + cl_vf.ToString() + sep + cl_f_max.ToString() + sep + 
 			cl_s_avg.ToString() + sep + cl_s_max.ToString() + sep + 
 			cl_p_avg.ToString() + sep + cl_p_max.ToString();
+
+		if(decimalSeparator == "COMMA")
+			str = Util.ConvertToComma(str);
+		else
+			str = Util.ConvertToPoint(str);
+			
+		if(decimalSeparator == "COMMA")
+			return Util.ChangeChars(str, ":::", ";");
+		else
+			return Util.ChangeChars(str, ":::", ",");
 	}
 }
 
@@ -488,12 +459,12 @@ public class EncoderSQL
 	public string extraWeight;
 	public string signalOrCurve;
 	public string filename;
-	public string url;
+	public string url;	//URL of data of signals and curves. Stored in DB as relative. Used in software as absolute. See SqliteEncoder
 	public int time;
 	public int minHeight;
 	public string description;
 	public string status;	//active or inactive curves
-	public string videoURL;	//URL of video of signals
+	public string videoURL;	//URL of video of signals. Stored in DB as relative. Used in software as absolute. See SqliteEncoder
 	
 	//encoderConfiguration conversions
 	//in signals and curves, need to do conversions (invert, inertiaMomentum, diameter)
@@ -624,7 +595,7 @@ public class EncoderSQL
 	}
 
 	//uniqueID:name
-	public void ChangePerson(string newIDAndName) {
+	public EncoderSQL ChangePerson(string newIDAndName) {
 		int newPersonID = Util.FetchID(newIDAndName);
 		string newPersonName = Util.FetchName(newIDAndName);
 		string newFilename = filename;
@@ -670,9 +641,17 @@ public class EncoderSQL
 		if(success)
 			filename = newFilename;
 
-		//SqliteUpdate
-		SqliteEncoder.Update(false, this);
+		//will update SqliteEncoder
+		return (this);
 	}
+
+
+	//used in NUnit
+	public string Filename
+	{
+		set { filename = value; }
+	}
+
 }
 
 
@@ -732,6 +711,19 @@ public class EncoderExercise
 		this.speed1RM = speed1RM;
 	}
 
+	public bool IsPredefined() {
+		if(
+				name == "Bench press" ||
+				name == "Squat" ||
+				name == "Free" ||
+				name == "Jump" ||
+				name == "Inclinated plane" ||
+				name == "Inclinated plane BW" )
+			return true;
+		else 
+			return false;
+	}
+
 	~EncoderExercise() {}
 }
 
@@ -889,9 +881,9 @@ public class EncoderConfiguration {
 		gearedDown = 1;
 	}
 
-	/* note: if this changes, change also in:
-	 * UtilEncoder.EncoderConfigurationList(enum encoderType)
-	 */
+	// note: if this changes, change also in:
+	// UtilEncoder.EncoderConfigurationList(enum encoderType)
+	
 	public EncoderConfiguration(Constants.EncoderConfigurationNames name) {
 		this.name = name;
 		has_d = false;
@@ -1142,5 +1134,4 @@ public class EncoderConfiguration {
 
 		return code + str_d + str_D + str_anglePush + str_angleWeight + str_inertia + str_gearedDown;
 	}
-	
 }
