@@ -460,7 +460,7 @@ public partial class ChronoJumpWindow
 			totalMass = findMass(Constants.MassType.DISPLACED);
 		} else {						//user curves
 			curvesData = SqliteEncoder.Select(
-					false, -1, currentPerson.UniqueID, currentSession.UniqueID, 
+					false, -1, currentPerson.UniqueID, currentSession.UniqueID, -1,
 					"curve", EncoderSQL.Eccons.ALL, 
 					true, true);
 		}
@@ -601,7 +601,7 @@ public partial class ChronoJumpWindow
 		"cl t" + "\n (ms)",
 		"cl rfd avg" + "\n (N/s/Kg)",
 		"cl i" + "\n (N*s/Kg)",
-		"cl f avg" + "\n (N)",
+		"cl f avg" + "\n (N/Kg)",
 		"cl vf" + "\n (N)",
 		"cl f max" + "\n (N)",
 		"cl s avg" + "\n (m/s)",
