@@ -19,6 +19,7 @@
  */
 
 using System;
+using Gdk;
 using Gtk;
 using Glade;
 //using Gnome;
@@ -69,6 +70,7 @@ public class GenericWindow
 	[Widget] Gtk.TreeView treeview;
 	[Widget] Gtk.Button button_accept;
 	[Widget] Gtk.Button button_cancel;
+	[Widget] Gtk.Button button_delete; //currently only on encoder exercise edit
 	
 	//treeview fake buttons
 	[Widget] Gtk.Button button_row_edit;
@@ -85,6 +87,8 @@ public class GenericWindow
 	[Widget] Gtk.Label label_spin_double2;
 	[Widget] Gtk.SpinButton spin_double2;
 	
+	[Widget] Gtk.Image image_delete;
+	
 	private ArrayList nonSensitiveRows;
 
 	static GenericWindow GenericWindowBox;
@@ -102,6 +106,10 @@ public class GenericWindow
 	public int TreeviewSelectedUniqueID;
 	private int commentColumn;
 
+	//used on encoder edit exercise
+	public int uniqueID;
+	public string nameUntranslated;
+
 	public GenericWindow ()
 	{
 		Glade.XML gladeXML;
@@ -124,8 +132,15 @@ public class GenericWindow
 		foreach(ArrayList widgetArray in array)
 			GenericWindowBox.showWidgetsPowerful(widgetArray);
 
+		GenericWindowBox.generic_window.Resizable = false;
 		GenericWindowBox.label_header.Text = textHeader;
-		//maybe more things have to be done before showing
+		
+		Pixbuf pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_delete.png");
+		GenericWindowBox.image_delete.Pixbuf = pixbuf;
+
+		GenericWindowBox.label_header.Text = textHeader;
+		
+		
 		if(showNow)
 			GenericWindowBox.generic_window.Show ();
 		GenericWindowBox.HideOnAccept = true;
@@ -144,6 +159,7 @@ public class GenericWindow
 		GenericWindowBox.hideWidgets();
 		GenericWindowBox.showWidget(stuff);
 
+		GenericWindowBox.generic_window.Resizable = false;
 		GenericWindowBox.label_header.Text = textHeader;
 		GenericWindowBox.generic_window.Show ();
 		GenericWindowBox.HideOnAccept = true;
@@ -183,21 +199,25 @@ public class GenericWindow
 		if(stuff == Constants.GenericWindowShow.ENTRY) {
 			entry.Show();
 			entry.IsEditable = editable;
+			entry.Sensitive = editable;
 			entry.Text = text;
 		}
 		else if(stuff == Constants.GenericWindowShow.ENTRY2) {
 			hbox_entry2.Show();
 			entry2.IsEditable = editable;
+			entry2.Sensitive = editable;
 			entry2.Text = text;
 		}
 		else if(stuff == Constants.GenericWindowShow.ENTRY3) {
 			hbox_entry3.Show();
 			entry3.IsEditable = editable;
+			entry3.Sensitive = editable;
 			entry3.Text = text;
 		}
 		else if(stuff == Constants.GenericWindowShow.SPININT) {
 			hbox_spin_int.Show();
 			spin_int.IsEditable = editable;
+			spin_int.Sensitive = editable;
 		}
 		else if(stuff == Constants.GenericWindowShow.SPINDOUBLE) {
 			spin_double.Show();
@@ -336,7 +356,7 @@ public class GenericWindow
 	}
 
 	
-	protected string [] comboCheckBoxesOptions = {
+	private string [] comboCheckBoxesOptions = {
 		Catalog.GetString("All"),
 		Catalog.GetString("None"),
 		Catalog.GetString("Invert"),
@@ -365,7 +385,7 @@ public class GenericWindow
 			UtilGtk.ComboMakeActive(comboCheckBoxesOptions, Catalog.GetString("Selected"));
 	}
 	
-	protected void on_combo_all_none_selected_changed(object o, EventArgs args) {
+	private void on_combo_all_none_selected_changed(object o, EventArgs args) {
 		string myText = UtilGtk.ComboGetActive(combo_all_none_selected);
 			
 		if (myText != "" & myText != Catalog.GetString("Selected")) {
@@ -377,7 +397,7 @@ public class GenericWindow
 		}
 	}
 	
-	protected void markSelected(string selected) {
+	private void markSelected(string selected) {
 		Gtk.TreeIter iter;
 		bool okIter = store.GetIterFirst(out iter);
 		if(okIter) {
@@ -539,7 +559,7 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 			return 0;
 	}
 
-	protected void createCheckboxes(TreeView tv) 
+	private void createCheckboxes(TreeView tv) 
 	{
 		CellRendererToggle crt = new CellRendererToggle();
 		crt.Visible = true;
@@ -586,7 +606,7 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 		}
 	}
 
-	protected void ItemToggled(object o, ToggledArgs args) {
+	private void ItemToggled(object o, ToggledArgs args) {
 		int column = 1;
 		TreeIter iter;
 		if (store.GetIter (out iter, new TreePath(args.Path))) 
@@ -683,7 +703,18 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 		treeview.Selection.GetSelected (out model, out iter);
 		store.SetValue (iter, commentColumn, entry_edit_row.Text);
 	}
-	
+
+	//this method is only used when try to delete an encoder exercise,
+	//and cannot because there are encoder rows done with this exercise.
+	//Just unsensitive some stuff now in order to not be able to change them
+	public void DeletingExerciseHideSomeWidgets() {
+		hbox_spin_int.Hide();
+		hbox_entry2.Hide();
+		hbox_entry3.Hide();
+		hbox_spin_double2.Hide();
+
+		SetButtonAcceptLabel(Catalog.GetString("Close"));
+	}	
 
 	public void RemoveSelectedRow () {
 		store = UtilGtk.RemoveRow(treeview, store);
@@ -699,7 +730,24 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 		//remove selected row from treeview
 		store = UtilGtk.RemoveRow(treeview, store);
 	}
+	
+	public void ShowTextview() {
+		scrolled_window_textview.Show();
+	}
 
+	public void ShowTreeview() {
+		scrolled_window_treeview.Show();
+	}
+
+	public void ShowButtonDelete(bool show) {
+		button_delete.Visible = show;
+	}
+	
+	private void on_button_delete_clicked (object o, EventArgs args)
+	{
+		GenericWindowBox.generic_window.Hide();
+		GenericWindowBox = null;
+	}
 	
 	public void SetButtonAcceptLabel(string str) {
 		button_accept.Label=str;
@@ -717,13 +765,13 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 		button_cancel.Visible = show;
 	}
 
-	protected void on_button_cancel_clicked (object o, EventArgs args)
+	private void on_button_cancel_clicked (object o, EventArgs args)
 	{
 		GenericWindowBox.generic_window.Hide();
 		GenericWindowBox = null;
 	}
 	
-	protected void on_delete_event (object o, DeleteEventArgs args)
+	private void on_delete_event (object o, DeleteEventArgs args)
 	{
 		args.RetVal = true;
 			
@@ -731,7 +779,7 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 		GenericWindowBox = null;
 	}
 
-	protected void on_button_accept_clicked (object o, EventArgs args)
+	private void on_button_accept_clicked (object o, EventArgs args)
 	{
 		if(HideOnAccept)
 			GenericWindowBox.generic_window.Hide();
@@ -745,6 +793,12 @@ Log.WriteLine("aaaaaaaaaaaaaaaa2");
 		GenericWindowBox.generic_window.Hide();
 		GenericWindowBox = null;
 	}
+	
+	public Button Button_delete {
+		set { button_delete = value; }
+		get { return button_delete; }
+	}
+		
 
 	public Button Button_accept {
 		set { button_accept = value; }
