@@ -852,11 +852,7 @@ public class PersonAddModifyWindow
 	[Widget] Gtk.ComboBox combo_countries;
 	
 	[Widget] Gtk.Image image_name;
-	[Widget] Gtk.Image image_date;
 	[Widget] Gtk.Image image_weight;
-	[Widget] Gtk.Image image_sport;
-	[Widget] Gtk.Image image_speciallity;
-	[Widget] Gtk.Image image_level;
 	
 	[Widget] Gtk.Button button_zoom;
 	[Widget] Gtk.Image image_photo_mini;
@@ -930,7 +926,6 @@ public class PersonAddModifyWindow
 		
 		createComboSports();
 		createComboSpeciallities(-1);
-		image_speciallity.Hide();
 		label_speciallity.Hide();
 		combo_speciallities.Hide();
 		createComboLevels();
@@ -969,7 +964,7 @@ public class PersonAddModifyWindow
 
 		if(adding) {
 			person_win.Title = Catalog.GetString ("New jumper");
-			button_accept.Sensitive = false;
+			//button_accept.Sensitive = false;
 		} else 
 			person_win.Title = Catalog.GetString ("Edit jumper");
 	}
@@ -1087,45 +1082,32 @@ public class PersonAddModifyWindow
 			image_weight.Show();
 			allOk = false;
 		}
-				
+	
+		/*		
 		if(dateTime != DateTime.MinValue)
 			image_date.Hide();
 		else {
 			image_date.Show();
 			allOk = false;
 		}
+		*/
 
-		if(UtilGtk.ComboGetActive(combo_sports) != Catalog.GetString(Constants.SportUndefined))
-			image_sport.Hide();
-		else {
-			image_sport.Show();
-			allOk = false;
-		}
-
-		if (! label_speciallity.Visible || 
-				UtilGtk.ComboGetActive(combo_speciallities) != Catalog.GetString(Constants.SpeciallityUndefined))
-			image_speciallity.Hide();
-		else {
-			image_speciallity.Show();
-			allOk = false;
-		}
-				
-		if(Util.FetchID(UtilGtk.ComboGetActive(combo_levels)) != Constants.LevelUndefinedID)
-			image_level.Hide();
-		else {
-			image_level.Show();
-			allOk = false;
-		}
-				
 		//countries is not required to create a person here, but will be required for server
 		//&& 
 		//UtilGtk.ComboGetActive(combo_continents) != Catalog.GetString(Constants.ContinentUndefined) &&
 		//UtilGtk.ComboGetActive(combo_countries) != Catalog.GetString(Constants.CountryUndefined)
 			
+		/*
 		if(allOk)
 			button_accept.Sensitive = true;
 		else
 			button_accept.Sensitive = false;
+		*/
+		/*
+		Always true because there's problems detecting the spinbutton change (when inserting data directly on entry)
+		and there's an error message after if there's missing data	
+		*/
+		button_accept.Sensitive = true;
 	}
 		
 	void on_radiobutton_man_toggled (object o, EventArgs args)
@@ -1581,28 +1563,29 @@ public class PersonAddModifyWindow
 	
 	void on_button_accept_clicked (object o, EventArgs args)
 	{
-		bool personExists;
-		if(adding)
-			personExists = Sqlite.Exists (false, Constants.PersonTable, Util.RemoveTilde(entry1.Text));
-		else
-			personExists = SqlitePerson.ExistsAndItsNotMe (currentPerson.UniqueID, Util.RemoveTilde(entry1.Text));
-
 		string errorMessage = "";
 
-		if(personExists) 
-			errorMessage += string.Format(Catalog.GetString("Person: '{0}' exists. Please, use another name"), Util.RemoveTildeAndColonAndDot(entry1.Text) );
-		else if (sport.Name == Catalog.GetString(Constants.SportUndefined)) 
-			errorMessage += Catalog.GetString("Please select an sport");
+		//Check if person name exists and weight is > 0
+		string personName = entry1.Text;
+		if(personName == "")
+			errorMessage += "\n" + Catalog.GetString("Please, write the name of the person.");
+		if((double) spinbutton_weight.Value == 0)
+			errorMessage += "\n" + Catalog.GetString("Please, complete the weight of the person.");
+		if(errorMessage.Length > 0) {
+			ErrorWindow.Show(errorMessage);
+			return;
+		}
 
-		//here sport shouldn't be undefined, then check 
-		//if it has speciallities and if they are selected
-		else if (sport.HasSpeciallities && 
-				UtilGtk.ComboGetActive(combo_speciallities) == Catalog.GetString(Constants.SpeciallityUndefined))
-			errorMessage += Catalog.GetString("Please select an speciallity");
-		else if (UtilGtk.ComboGetActive(combo_levels) ==
-				Constants.LevelUndefinedID.ToString() + ":" + 
-			       	Catalog.GetString(Constants.LevelUndefined))
-			errorMessage += Catalog.GetString("Please select a level");
+
+		bool personExists;
+		if(adding)
+			personExists = Sqlite.Exists (false, Constants.PersonTable, Util.RemoveTilde(personName));
+		else
+			personExists = SqlitePerson.ExistsAndItsNotMe (currentPerson.UniqueID, Util.RemoveTilde(personName));
+
+		if(personExists) 
+			errorMessage += string.Format(Catalog.GetString("Person: '{0}' exists. Please, use another name"), 
+					Util.RemoveTildeAndColonAndDot(personName) );
 		else {
 			//if weight has changed
 			if(!adding && (double) spinbutton_weight.Value != weightIni) {
@@ -1661,7 +1644,7 @@ public class PersonAddModifyWindow
 					Constants.RaceUndefinedID,
 					Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_countries), countries)),
 					textview_description.Buffer.Text,
-					Constants.ServerUndefinedID);
+					Constants.ServerUndefinedID, false); //dbconOpened
 					
 			currentPersonSession = new PersonSession (
 					currentPerson.UniqueID, currentSession.UniqueID, 
@@ -1669,7 +1652,7 @@ public class PersonAddModifyWindow
 					sport.UniqueID, 
 					Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_speciallities), speciallities)),
 					Util.FetchID(UtilGtk.ComboGetActive(combo_levels)),
-					textview_ps_comments.Buffer.Text);
+					textview_ps_comments.Buffer.Text, false); //dbconOpened
 		} else {
 			//here we update rows in the database
 			currentPerson = new Person (currentPerson.UniqueID, entry1.Text, sex, dateTime, 
@@ -1691,7 +1674,7 @@ public class PersonAddModifyWindow
 						sport.UniqueID, 
 						Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_speciallities), speciallities)),
 						Util.FetchID(UtilGtk.ComboGetActive(combo_levels)),
-						textview_ps_comments.Buffer.Text);
+						textview_ps_comments.Buffer.Text, false); //dbconOpened
 			else {
 				//don't come from recuperate
 				//we only need to update personSession
@@ -2197,8 +2180,10 @@ public class PersonAddMultipleWindow {
 		errorRepeatedEntryString = "";
 		personsCreatedCount = 0;
 
+		Sqlite.Open();
 		for (int i = 0; i < rows; i ++) 
 			checkEntries(i, ((Gtk.Entry)entries[i]).Text.ToString(), (int) ((Gtk.SpinButton)spins[i]).Value);
+		Sqlite.Close();
 	
 		checkAllEntriesAreDifferent();
 
@@ -2208,16 +2193,16 @@ public class PersonAddMultipleWindow {
 		if (combinedErrorString.Length > 0) {
 			ErrorWindow.Show(combinedErrorString);
 		} else {
-			prepareAllNonBlankRows();
+			processAllNonBlankRows();
 		
 			PersonAddMultipleWindowBox.person_multiple_infinite.Hide();
 			PersonAddMultipleWindowBox = null;
 		}
 	}
 		
-	void checkEntries(int count, string name, double weight) {
+	private void checkEntries(int count, string name, double weight) {
 		if(name.Length > 0) {
-			bool personExists = Sqlite.Exists (false, Constants.PersonTable, Util.RemoveTilde(name));
+			bool personExists = Sqlite.Exists (true, Constants.PersonTable, Util.RemoveTilde(name));
 			if(personExists) {
 				errorExistsString += "[" + (count+1) + "] " + name + "\n";
 			}
@@ -2265,43 +2250,58 @@ public class PersonAddMultipleWindow {
 
 	//inserts all the rows where name is not blank
 	//all this names doesn't match with other in the database, and the weights are > 0 ( checked in checkEntries() )
-	void prepareAllNonBlankRows() 
+	void processAllNonBlankRows() 
 	{
-		//the last is the first for having the first value inserted as currentPerson
-		for (int i = rows -1; i >= 0; i --) 
-			if(((Gtk.Entry)entries[i]).Text.ToString().Length > 0)
-				insertPerson (
-						((Gtk.Entry)entries[i]).Text.ToString(), 
-						((Gtk.RadioButton)radiosM[i]).Active, 
-		 				(double) ((Gtk.SpinButton)spins[i]).Value);
-	}
+		int maxPUniqueID = Sqlite.Max(Constants.PersonTable, "uniqueID", false);
+		int pID = maxPUniqueID + 1;
+		int maxPSUniqueID = Sqlite.Max(Constants.PersonSessionTable, "uniqueID", false);
+		int psID = maxPSUniqueID + 1;
+		string sex = "";
+		double weight = 0;
+				
+		List <Person> persons = new List<Person>();
+		List <PersonSession> personSessions = new List<PersonSession>();
 
-	void insertPerson (string name, bool male, double weight) 
-	{
-		string sex = Constants.F;
-		if(male) { sex = Constants.M; }
-
-		//now dateTime is undefined until user changes it
 		DateTime dateTime = DateTime.MinValue;
 
-		currentPerson = new Person ( name, sex, dateTime, 
-				Constants.RaceUndefinedID,
-				Constants.CountryUndefinedID,
-				"", 			//description
-				Constants.ServerUndefinedID);
+		//the last is the first for having the first value inserted as currentPerson
+		for (int i = rows -1; i >= 0; i --) 
+			if(((Gtk.Entry)entries[i]).Text.ToString().Length > 0) 
+			{
+				sex = Constants.F;
+				if(((Gtk.RadioButton)radiosM[i]).Active) { sex = Constants.M; }
+
+				currentPerson = new Person(
+							pID ++,
+							((Gtk.Entry)entries[i]).Text.ToString(), //name
+							sex,
+							dateTime,
+							Constants.RaceUndefinedID,
+							Constants.CountryUndefinedID,
+							"", 					//description
+							Constants.ServerUndefinedID
+							);
 				
+				persons.Add(currentPerson);
+						
+				weight = (double) ((Gtk.SpinButton)spins[i]).Value;
+				personSessions.Add(new PersonSession(
+							psID ++,
+							currentPerson.UniqueID, currentSession.UniqueID, 
+							0, weight, 		//height, weight	
+							currentSession.PersonsSportID,
+							currentSession.PersonsSpeciallityID,
+							currentSession.PersonsPractice,
+							"") 			//comments
+						);
 
-		new PersonSession (
-				currentPerson.UniqueID, currentSession.UniqueID, 
-				0, weight, 		//height, weight	
-				currentSession.PersonsSportID,
-				currentSession.PersonsSpeciallityID,
-				currentSession.PersonsPractice,
-				""); 			//comments
-
-		personsCreatedCount ++;
-	}
+				personsCreatedCount ++;
+			}
 	
+		//do the transaction	
+		SqlitePersonSessionTransaction psTr = new SqlitePersonSessionTransaction(persons, personSessions);
+	}
+
 	public Button Button_accept 
 	{
 		set {
