@@ -188,6 +188,7 @@ public partial class ChronoJumpWindow {
 	
 	private static string [] comboStatsSubTypeSimpleOptions = {
 		Catalog.GetString("No indexes"), 
+		//Constants.ChronojumpProfile,
 		Constants.FvIndexFormula,
 		Constants.IeIndexFormula, 
 		Constants.ArmsUseIndexFormula,
@@ -589,7 +590,7 @@ public partial class ChronoJumpWindow {
 			//by default show all simple nonTC jumps, but if combo_stats_subtype changed
 			//updateComboStatsSubType() will do the work
 			UtilGtk.ComboUpdate(combo_stats_stat_apply_to, 
-				SqliteJumpType.SelectJumpTypes(Constants.AllJumpsName, "nonTC", true), ""); //only select name
+				SqliteJumpType.SelectJumpTypes(false, Constants.AllJumpsName, "nonTC", true), ""); //only select name
 			combo_stats_stat_apply_to.Sensitive = true;
 			combo_stats_stat_apply_to.Active = 0;
 		} 
@@ -600,7 +601,7 @@ public partial class ChronoJumpWindow {
 			combo_stats_stat_subtype.Active = 0;
 			
 			UtilGtk.ComboUpdate(combo_stats_stat_apply_to, 
-				SqliteJumpType.SelectJumpTypes(Constants.AllJumpsName, "TC", true), ""); //only select name
+				SqliteJumpType.SelectJumpTypes(false, Constants.AllJumpsName, "TC", true), ""); //only select name
 			combo_stats_stat_apply_to.Sensitive = true;
 			combo_stats_stat_apply_to.Active = 0;
 		} 
@@ -651,9 +652,13 @@ public partial class ChronoJumpWindow {
 		{
 			if(UtilGtk.ComboGetActive(combo_stats_stat_subtype) == Catalog.GetString("No indexes")) {
 				UtilGtk.ComboUpdate(combo_stats_stat_apply_to, 
-					SqliteJumpType.SelectJumpTypes(Constants.AllJumpsName, "nonTC", true), ""); //only select name
+					SqliteJumpType.SelectJumpTypes(false, Constants.AllJumpsName, "nonTC", true), ""); //only select name
 				combo_stats_stat_apply_to.Sensitive = true;
 				combo_stats_stat_apply_to.Active = 0;
+			} else if (UtilGtk.ComboGetActive(combo_stats_stat_subtype) == Constants.ChronojumpProfile) {
+				UtilGtk.ComboUpdate(combo_stats_stat_apply_to, "SJ, SJl 100%, CMJ, ABK, DJa");
+				combo_stats_stat_apply_to.Active = 0;
+				combo_stats_stat_apply_to.Sensitive = false;
 			} else if (UtilGtk.ComboGetActive(combo_stats_stat_subtype) == Constants.IeIndexFormula) {
 				UtilGtk.ComboUpdate(combo_stats_stat_apply_to, "CMJ, SJ");
 				combo_stats_stat_apply_to.Active = 0;
@@ -677,9 +682,9 @@ public partial class ChronoJumpWindow {
 				combo_stats_stat_apply_to.Sensitive = false;
 			} else if (UtilGtk.ComboGetActive(combo_stats_stat_subtype) == Catalog.GetString(Constants.SubtractionBetweenTests)) {
 				UtilGtk.ComboUpdate(combo_subtraction_between_1, 
-					SqliteJumpType.SelectJumpTypes("", "", true), ""); //only select name
+					SqliteJumpType.SelectJumpTypes(false, "", "", true), ""); //only select name
 				UtilGtk.ComboUpdate(combo_subtraction_between_2, 
-					SqliteJumpType.SelectJumpTypes("", "", true), ""); //only select name
+					SqliteJumpType.SelectJumpTypes(false, "", "", true), ""); //only select name
 				//subtraction_between_tests_show(true);
 				showSubtractionBetweenTests = true;
 				label_apply_to.Visible = false;
@@ -688,7 +693,7 @@ public partial class ChronoJumpWindow {
 			} else if (UtilGtk.ComboGetActive(combo_stats_stat_subtype) == Constants.PotencySayersSJFormulaShort) {
 				combo_stats_stat_apply_to.Active = 
 					UtilGtk.ComboUpdate(combo_stats_stat_apply_to, 
-							SqliteJumpType.SelectJumpTypes("", "nonTC", true), //only select name
+							SqliteJumpType.SelectJumpTypes(false, "", "nonTC", true), //only select name
 							"SJ"); //default value
 				combo_stats_stat_apply_to.Sensitive = false;
 			} else {/*
@@ -707,14 +712,14 @@ public partial class ChronoJumpWindow {
 				*/
 				combo_stats_stat_apply_to.Active = 
 					UtilGtk.ComboUpdate(combo_stats_stat_apply_to, 
-							SqliteJumpType.SelectJumpTypes("", "nonTC", true), //only select name
+							SqliteJumpType.SelectJumpTypes(false, "", "nonTC", true), //only select name
 							"CMJ"); //default value
 				combo_stats_stat_apply_to.Sensitive = false;
 			}
 		}  else if (UtilGtk.ComboGetActive(combo_stats_stat_type) == Constants.TypeJumpsSimpleWithTC ) 
 		{
 			UtilGtk.ComboUpdate(combo_stats_stat_apply_to, 
-				SqliteJumpType.SelectJumpTypes(Constants.AllJumpsName, "TC", true), ""); //only select name
+				SqliteJumpType.SelectJumpTypes(false, Constants.AllJumpsName, "TC", true), ""); //only select name
 			combo_stats_stat_apply_to.Sensitive = true;
 			combo_stats_stat_apply_to.Active = 0;
 		} 
@@ -730,6 +735,9 @@ public partial class ChronoJumpWindow {
 			checkbutton_transposed.Sensitive = false;
 			UtilGtk.ComboUpdate(combo_graph_type, Util.StringToStringArray(Constants.GraphTypeLines), "");
 			combo_graph_type.Active=0;
+		} else if (radiobutton_selected_sessions.Active) {
+			//on multi session use only barplot and lines
+			combo_graph_type.Active = UtilGtk.ComboUpdate(combo_graph_type, Constants.GraphTypesMultisession, Constants.GraphTypeLines);
 		} else {
 			//hbox_mark_consecutives.Hide();
 			checkbutton_transposed.Active = false;
@@ -852,26 +860,22 @@ public partial class ChronoJumpWindow {
 		button_add_to_report.Sensitive = true;
 
 		GraphROptions graphROptions = fillGraphROptions();
-		
+	
 		myStatType = new StatType(
 				statisticType,
 				statisticSubType,
 				statisticApplyTo,
 				treeview_stats,
 				sendSelectedSessions, 
-				prefsDigitsNumber, 
 				checkbutton_stats_sex.Active,  
 				statsJumpsType,
 				limit, 
-				heightPreferred,
-				weightPercentPreferred, 
 				markedRows,
 				evolution_mark_consecutives,
 				graphROptions,
 				graph,
 				toReport,  //always false in this class
-				RGraphsTranslate,
-				useHeightsOnJumpIndexes
+				preferences
 				);
 
 		//if we just made a graph, store is not made, 
@@ -1082,6 +1086,15 @@ public partial class ChronoJumpWindow {
 			radiobutton_stats_jumps_person_bests.Sensitive = false;
 			radiobutton_stats_jumps_person_average.Sensitive = false;
 		}
+		else if(statisticType == Constants.TypeJumpsSimple && statisticSubType == Constants.ChronojumpProfile) {
+			//on Chronojump profile only best jumps are used
+			radiobutton_stats_jumps_person_bests.Active = true;
+			//make no sensitive
+			spin_stats_jumps_person_bests.Sensitive = false;
+			radiobutton_stats_jumps_all.Sensitive = false;
+			radiobutton_stats_jumps_limit.Sensitive = false;
+			radiobutton_stats_jumps_person_average.Sensitive = false;
+		}
 		else if(statisticType == Constants.TypeSessionSummary || 
 				statisticType == Constants.TypeJumperSummary || 
 				( statisticType == Constants.TypeJumpsSimple && 
@@ -1171,17 +1184,24 @@ public partial class ChronoJumpWindow {
 			//single session can have all graph types
 			combo_graph_type.Active = UtilGtk.ComboUpdate(
 					combo_graph_type, Constants.GraphTypes, UtilGtk.ComboGetActive(combo_graph_type));
+			//except
+			if ( UtilGtk.ComboGetActive(combo_stats_stat_subtype) == Catalog.GetString("Evolution") ||
+					UtilGtk.ComboGetActive(combo_stats_stat_type) == Constants.TypeRunsIntervallic ) {
+				notebook_stats_win_options.Show();
+				checkbutton_transposed.Active = true;
+				checkbutton_transposed.Sensitive = false;
+				UtilGtk.ComboUpdate(combo_graph_type, Util.StringToStringArray(Constants.GraphTypeLines), "");
+				combo_graph_type.Active=0;
+			} else
+				notebook_stats_win_options.Hide();
 		} 
 		else if (o == (object) radiobutton_selected_sessions ) 
 		{
 			Log.WriteLine("selected");
 			button_stats_select_sessions.Sensitive = true;
 			
-			//multi session cannot have XY and dotchart
-			string [] types = Util.DeleteString(Constants.GraphTypes, Constants.GraphTypeXY);
-			types = Util.DeleteString(types, Constants.GraphTypeDotchart);
-			combo_graph_type.Active = UtilGtk.ComboUpdate(
-					combo_graph_type, types, UtilGtk.ComboGetActive(combo_graph_type));
+			//multi session use only barplot and lines
+			combo_graph_type.Active = UtilGtk.ComboUpdate(combo_graph_type, Constants.GraphTypesMultisession, Constants.GraphTypeLines);
 		}
 		update_stats_widgets_sensitiveness();
 		showUpdateStatsAndHideData(true);
