@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 
@@ -48,22 +48,33 @@ class SqliteCountry : Sqlite
 	{
 		conversionSubRateTotal = countries.Length;
 		conversionSubRate = 0;
-		foreach(string myString in countries) {
-			//put in db only english name
-			string [] strFull = myString.Split(new char[] {':'});
-			Insert(
-					true,   		//dbconOpened
-					strFull[3], 		//code
-					strFull[1], 		//name (english)
-					strFull[0]		//continent
-			      );
-			conversionSubRate ++;
+
+		using(SqliteTransaction tr = dbcon.BeginTransaction())
+		{
+			using (SqliteCommand dbcmdTr = dbcon.CreateCommand())
+			{
+				dbcmdTr.Transaction = tr;
+	
+				foreach(string myString in countries) {
+					//put in db only english name
+					string [] strFull = myString.Split(new char[] {':'});
+					Insert(
+							true,   		//dbconOpened
+							dbcmdTr,
+							strFull[3], 		//code
+							strFull[1], 		//name (english)
+							strFull[0]		//continent
+					      );
+					conversionSubRate ++;
+				}
+			}
+			tr.Commit();
 		}
 	}
-	public static int Insert(bool dbconOpened, string code, string nameEnglish, string continent)
+	public static void Insert(bool dbconOpened, SqliteCommand mycmd, string code, string nameEnglish, string continent)
 	{
 		if(! dbconOpened)
-			dbcon.Open();
+			Sqlite.Open();
 
 		string myString = "INSERT INTO " + Constants.CountryTable + 
 			//" (uniqueID, code, name, continent) VALUES (NULL, '" + code + "', '" + 
@@ -72,24 +83,25 @@ class SqliteCountry : Sqlite
 			" (uniqueID, code, name, continent) VALUES (NULL, \"" + code + "\", \"" + 
 			nameEnglish + "\", \"" + continent + "\")";
 
-		dbcmd.CommandText = myString;
-		dbcmd.ExecuteNonQuery();
+		mycmd.CommandText = myString;
+		Log.WriteLine(mycmd.CommandText.ToString());
+		mycmd.ExecuteNonQuery();
 
+		/*
 		//int myLast = dbcon.LastInsertRowId;
 		//http://stackoverflow.com/questions/4341178/getting-the-last-insert-id-with-sqlite-net-in-c
 		myString = @"select last_insert_rowid()";
-		dbcmd.CommandText = myString;
+		mycmd.CommandText = myString;
 		int myLast = Convert.ToInt32(dbcmd.ExecuteScalar()); // Need to type-cast since `ExecuteScalar` returns an object.
+		*/
 
 		if(! dbconOpened)
-			dbcon.Close();
-
-		return myLast;
+			Sqlite.Close();
 	}
 
 	public static string [] SelectCountriesOfAContinent(string continent, bool insertUndefined)
 	{
-		dbcon.Open();
+		Sqlite.Open();
 		
 		dbcmd.CommandText = "SELECT uniqueID, name FROM " + Constants.CountryTable + " WHERE continent == '" + continent + "'";
 		
@@ -104,7 +116,7 @@ class SqliteCountry : Sqlite
 					reader[1].ToString() + ":" + 
 					Catalog.GetString(reader[1].ToString()));
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 
 		int count = 0;
 		string [] myReturn;
@@ -124,7 +136,7 @@ class SqliteCountry : Sqlite
 	
 	public static string [] Select(int uniqueID)
 	{
-		dbcon.Open();
+		Sqlite.Open();
 		
 		dbcmd.CommandText = "SELECT * FROM " + Constants.CountryTable + " WHERE uniqueID == " + uniqueID;
 		
@@ -142,7 +154,7 @@ class SqliteCountry : Sqlite
 		myReturn[3] = reader[3].ToString(); //continent
 		
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myReturn;
 	}
 
@@ -254,7 +266,6 @@ class SqliteCountry : Sqlite
 		"Asia:" + "China:" + Catalog.GetString("China") + ":" + "CHN",
 		"Asia:" + "Christmas Island:" + Catalog.GetString("Christmas Island") + ":" + "CXR",
 		"Asia:" + "Cocos (Keeling) Islands:" + Catalog.GetString("Cocos (Keeling) Islands") + ":" + "CCK",
-		"Asia:" + "Cyprus:" + Catalog.GetString("Cyprus") + ":" + "CYP",
 		"Asia:" + "Georgia:" + Catalog.GetString("Georgia") + ":" + "GEO",
 		"Asia:" + "Hong Kong:" + Catalog.GetString("Hong Kong") + ":" + "HKG",
 		"Asia:" + "India:" + Catalog.GetString("India") + ":" + "IND",
@@ -305,6 +316,7 @@ class SqliteCountry : Sqlite
 		"Europe:" + "Bosnia and Herzegovina:" + Catalog.GetString("Bosnia and Herzegovina") + ":" + "BIH",
 		"Europe:" + "Bulgaria:" + Catalog.GetString("Bulgaria") + ":" + "BGR",
 		"Europe:" + "Croatia:" + Catalog.GetString("Croatia") + ":" + "HRV",
+		"Europe:" + "Cyprus:" + Catalog.GetString("Cyprus") + ":" + "CYP",
 		"Europe:" + "Czech Republic:" + Catalog.GetString("Czech Republic") + ":" + "CZE",
 		"Europe:" + "Denmark:" + Catalog.GetString("Denmark") + ":" + "DNK",
 		"Europe:" + "Estonia:" + Catalog.GetString("Estonia") + ":" + "EST",
@@ -469,7 +481,8 @@ class SqliteCountry : Sqlite
 	:'<,'>s/\(.*\),\(.*\):\(.*\),\(.*\))\(.*$\)/\1:\3")\5/
 
 	except: congo, korea, Dominica
-	
+
+	1.16 Cyprus has been moved from Asia to Europe	
 	*/
 
 }
