@@ -22,6 +22,7 @@ using System;
 using System.Data;
 using System.IO;
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List<T>
 using Mono.Unix;
 using Mono.Data.Sqlite;
 
@@ -62,7 +63,7 @@ class SqliteStat : Sqlite
 			orderByString = orderByString + tp + ".name, sessionID, ";
 		}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, sessionID, " + moreSelect +
 			fromString +
 			sessionString +
@@ -107,7 +108,7 @@ class SqliteStat : Sqlite
 			}
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 	
@@ -153,7 +154,7 @@ class SqliteStat : Sqlite
 			orderByString = orderByString + "" + tp + ".name, jump.sessionID, ";
 		}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, jump.sessionID, " + moreSelect +
 			fromString +
 			sessionString +
@@ -213,7 +214,7 @@ class SqliteStat : Sqlite
 			}
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 
@@ -314,7 +315,7 @@ class SqliteStat : Sqlite
 			orderByString = orderByString + tp + ".name, jump.sessionID, ";
 		}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, jump.sessionID, " + moreSelect +
 			fromString +
 			sessionString +
@@ -378,7 +379,7 @@ class SqliteStat : Sqlite
 				    );
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 
@@ -420,7 +421,7 @@ class SqliteStat : Sqlite
 			orderByString = orderByString + tp + ".name, jumpRj.sessionID, ";
 		}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, sessionID, " + moreSelect +
 			//" FROM jumpRj, person " +
 			fromString +
@@ -473,7 +474,7 @@ class SqliteStat : Sqlite
 				    );
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 
@@ -517,7 +518,7 @@ class SqliteStat : Sqlite
 			orderByString = orderByString + tp + ".name, jumpRj.sessionID, ";
 		}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, sessionID, " + moreSelect +
 			fromString +
 			sessionString +
@@ -575,7 +576,7 @@ class SqliteStat : Sqlite
 				    );
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 
@@ -583,7 +584,7 @@ class SqliteStat : Sqlite
 	//for rjEvolution (to know the number of columns)
 	public static int ObtainMaxNumberOfJumps (string sessionString)
 	{
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT MAX(jumps) from jumpRj " + sessionString +
 			"group by jumps order by jumps DESC limit 1";
 			//this is done because if no jumps, and we don't write last line, it returns a blank line
@@ -600,7 +601,7 @@ class SqliteStat : Sqlite
 			myReturn = Convert.ToInt32(reader[0].ToString());
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 
 		if (found) {
 			return myReturn;
@@ -612,7 +613,7 @@ class SqliteStat : Sqlite
 	//for start/RunIntervallic (to know the number of columns)
 	public static int ObtainMaxNumberOfRuns (string sessionString)
 	{
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT MAX(tracks) from runInterval " + sessionString +
 			"group by tracks order by tracks DESC limit 1";
 			//this is done because if no jumps, and we don't write last line, it returns a blank line
@@ -631,7 +632,7 @@ class SqliteStat : Sqlite
 			myReturn = Convert.ToInt32(Math.Floor(Convert.ToDouble(reader[0].ToString())));
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 
 		if (found) {
 			return myReturn;
@@ -703,7 +704,7 @@ class SqliteStat : Sqlite
 			orderByString = orderByString + tp + ".name, jumpRj.sessionID, ";
 		}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, sessionID, " + moreSelect +
 			fromString +
 			sessionString +
@@ -765,7 +766,7 @@ class SqliteStat : Sqlite
 				    );
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 
@@ -811,7 +812,7 @@ class SqliteStat : Sqlite
 		//	orderByString = orderByString + tp + ".name, jumpRj.sessionID, ";
 		//}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, sessionID, " + moreSelect +
 			fromString +
 			sessionString +
@@ -866,7 +867,7 @@ Log.WriteLine(intervalSpeeds);
 				    );
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 
@@ -906,7 +907,7 @@ Log.WriteLine(intervalSpeeds);
 			orderByString = orderByString + tp + ".name, j1.sessionID, ";
 		}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, j1.sessionID, " + moreSelect +
 			" FROM jump AS j1, jump AS j2, " + tp + " " +
 			sessionString +
@@ -949,7 +950,7 @@ Log.WriteLine(intervalSpeeds);
 				    );
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 	
@@ -983,7 +984,7 @@ Log.WriteLine(intervalSpeeds);
 			orderByString = orderByString + tp + ".name, j1.sessionID, ";
 		}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, j1.sessionID, " + moreSelect +
 			" FROM jump AS j1, jump AS j2, " + tp + " " +
 			sessionString +
@@ -1027,7 +1028,7 @@ Log.WriteLine(intervalSpeeds);
 				    );
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 
@@ -1061,7 +1062,7 @@ Log.WriteLine(intervalSpeeds);
 			orderByString = orderByString + tp + ".name, j1.sessionID, ";
 		}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, j1.sessionID, " + moreSelect +
 			" FROM jump AS j1, jump AS j2, " + tp + " " +
 			sessionString +
@@ -1111,7 +1112,7 @@ Log.WriteLine(intervalSpeeds);
 				    );
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 
@@ -1216,7 +1217,7 @@ Log.WriteLine(intervalSpeeds);
 			orderByString = orderByString + "jump.sessionID, ";
 		}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, jump.sessionID, " + moreSelect +
 			fromString +
 			sessionString +
@@ -1286,7 +1287,7 @@ Log.WriteLine(intervalSpeeds);
 			}
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 
@@ -1328,7 +1329,7 @@ Log.WriteLine(intervalSpeeds);
 			orderByString = orderByString + tp + ".name, sessionID, ";
 		}
 		
-		dbcon.Open();
+		Sqlite.Open();
 		dbcmd.CommandText = "SELECT " + tp + ".name, " + tp + ".sex, sessionID, " + moreSelect +
 			fromString +
 			sessionString +
@@ -1373,9 +1374,84 @@ Log.WriteLine(intervalSpeeds);
 			}
 		}
 		reader.Close();
-		dbcon.Close();
+		Sqlite.Close();
 		return myArray;
 	}
 	
+	/*
+	 * TODO: Al this have to be in % then need all the data to do it
+	maximum values of each jump!!!!
+	all with heights
+	SJ100		F Max
+	SJ-SJ100 	F Expl
+	CMJ-SJ 		Cap. Elastica (hability)
+	ABK-CMJ 	Cap. Braços (hability)
+	DJa		F Reactiu-reflexa
+	*/
+	public static ArrayList SelectChronojumpProfile (string sessionID)
+	{
+		Sqlite.Open();
+		
+		//select personID and personName (IDNameList)
+		IDNameList idNameList = fillIDNameList( 
+				"SELECT personSession77.personID, person77.name FROM personSession77, person77 " +
+				"WHERE personSession77.sessionID == " + sessionID +
+				" AND personSession77.personID == person77.uniqueID");
+
+
+		//select personID and each index (using IDDoubleLists)
+		IDDoubleList listFMax = fillIDDoubleList( 
+				"SELECT personID, MAX(jump.tv * jump.tv * 1.226) " +
+				" FROM jump " +
+				" WHERE type == 'SJl' AND jump.weight == 100 " +
+				" AND sessionID == " + sessionID + " GROUP BY personID");
 	
+		IDDoubleList listFExpl = fillIDDoubleList( 
+				"SELECT j1.personID, MAX(j1.tv * j1.tv * 1.226) - MAX(j2.tv * j2.tv * 1.226) AS myIndex " +
+				" FROM jump AS j1, jump AS j2 " +
+				" WHERE j1.type == 'SJ' AND j2.type == 'SJl' AND j2.weight=100 " +
+				" AND j1.personID == j2.personID " +
+				" AND j1.sessionID == " + sessionID + " AND j2.sessionID == " + sessionID + 
+				" GROUP BY j1.personID");
+
+		IDDoubleList listCElast = fillIDDoubleList( 
+				"SELECT j1.personID, MAX(j1.tv * j1.tv * 1.226) - MAX(j2.tv * j2.tv * 1.226) AS myIndex " +
+				" FROM jump AS j1, jump AS j2 " +
+				" WHERE j1.type == 'CMJ' AND j2.type == 'SJ' " +
+				" AND j1.personID == j2.personID " +
+				" AND j1.sessionID == " + sessionID + " AND j2.sessionID == " + sessionID + 
+				" GROUP BY j1.personID");
+	
+		IDDoubleList listCArms = fillIDDoubleList( 
+				"SELECT j1.personID, MAX(j1.tv * j1.tv * 1.226) - MAX(j2.tv * j2.tv * 1.226) AS myIndex " +
+				" FROM jump AS j1, jump AS j2 " +
+				" WHERE j1.type == 'ABK' AND j2.type == 'CMJ' " +
+				" AND j1.personID == j2.personID " +
+				" AND j1.sessionID == " + sessionID + " AND j2.sessionID == " + sessionID + 
+				" GROUP BY j1.personID");
+
+		IDDoubleList listFReact = fillIDDoubleList( 
+				"SELECT personID, MAX(jump.tv * jump.tv * 1.226) " +
+				" FROM jump WHERE type == 'DJa' " +
+				" AND sessionID == " + sessionID + " GROUP BY personID");
+	
+		
+		ArrayList array = new ArrayList();
+		array.Add(listFMax);
+		array.Add(listFExpl);
+		array.Add(listCElast);
+		array.Add(listCArms);
+		array.Add(listFReact);
+
+		//print all	
+		IDNameIDDoubleListOfLists superlist = new IDNameIDDoubleListOfLists(idNameList, array);
+		Log.WriteLine("superlist");
+		Log.WriteLine( Util.StringArrayToString(superlist.GetStringArray(),"\n") );
+		ArrayList arrayReturn = superlist.GetArray();
+		Log.WriteLine("end of superlist");
+		
+		Sqlite.Close();
+		return arrayReturn;
+	}
+
 }
