@@ -109,11 +109,11 @@ public class Stat
 	{
 		//TODO: check, this is weird...
 		this.sessions = myStatTypeStruct.SendSelectedSessions;
-		pDN = myStatTypeStruct.PrefsDigitsNumber;
+		pDN = myStatTypeStruct.preferences.digitsNumber;
 		this.showSex = myStatTypeStruct.Sex_active;
 		this.statsJumpsType = myStatTypeStruct.StatsJumpsType;
-		this.heightPreferred = myStatTypeStruct.HeightPreferred;
-		this.weightStatsPercent = myStatTypeStruct.WeightStatsPercent;
+		this.heightPreferred = myStatTypeStruct.preferences.heightPreferred;
+		this.weightStatsPercent = myStatTypeStruct.preferences.weightStatsPercent;
 		this.statsJumpsType = myStatTypeStruct.StatsJumpsType;
 		this.limit = myStatTypeStruct.Limit;
 		this.jumpType = myStatTypeStruct.StatisticApplyTo;
@@ -122,8 +122,8 @@ public class Stat
 		
 		this.gRO = myStatTypeStruct.GRO;
 		this.toReport = myStatTypeStruct.ToReport;
-		this.graphTranslate = myStatTypeStruct.GraphTranslate;
-		this.useHeightsOnJumpIndexes = myStatTypeStruct.UseHeightsOnJumpIndexes;
+		this.graphTranslate = myStatTypeStruct.preferences.RGraphsTranslate;
+		this.useHeightsOnJumpIndexes = myStatTypeStruct.preferences.useHeightsOnJumpIndexes;
 		
 		this.treeview = treeview;
 		
@@ -918,7 +918,9 @@ public class Stat
 		string xyFirstFound = "";
 		int count = 0; //this counts accepted series
 		int countCols=0;
+		int countRows=0; //on multisession, names of persons come in rows. Use this to discard some rows if unselected on treeview (! markedRows)
 		foreach(GraphSerie serie in GraphSeries) {
+			Log.WriteLine("serie:" + serie.Title);
 			if(
 					side == Sides.LEFT && ! serie.IsLeftAxis ||
 					side == Sides.RIGHT && serie.IsLeftAxis) {
@@ -929,6 +931,12 @@ public class Stat
 			if(sessions.Count > 1 && serie.Title == Catalog.GetString("AVG"))
 				continue;
 
+			//on multisession, names of persons come in rows. Use this to discard some rows if unselected on treeview (! markedRows)
+			if(sessions.Count > 1 && ! acceptCheckedData(countRows)) {
+				countRows ++;
+				continue;
+			}
+
 			//on XY only take two vars
 			if(gro.Type == Constants.GraphTypeXY) {
 				Log.WriteLine("groVarX: " + gro.VarX + " groVarY: " + gro.VarY + " tit: " + serie.Title);
@@ -952,16 +960,19 @@ public class Stat
 			string sep = "";
 			countCols=0;
 			foreach(string val in serie.SerieData) {
+				Log.Write(" val:" + val);
 				bool use = true;
-				if(! acceptCheckedData(countCols)) 
+
+				//on simplesession, cols are persons. See if they are discarded on markedRows
+				if(sessions.Count == 1 && ! acceptCheckedData(countCols))
 					use = false;
 
 				//don't plot AVG col on multisession
-				if(sessions.Count > 1 && countCols == serie.SerieData.Count) 
+				if(sessions.Count > 1 && countCols == serie.SerieData.Count)
 					use = false;
 				
 				//don't plot SD col on multisession
-				if(sessions.Count > 1 && countCols +1 == serie.SerieData.Count) 
+				if(sessions.Count > 1 && countCols +1 == serie.SerieData.Count)
 					use = false;
 
 				countCols++;
@@ -980,13 +991,15 @@ public class Stat
 			colNamesD += sepSerie + "'" + Util.RemoveTilde(serie.Title)  + "'";
 			sepSerie = ", ";
 			count ++;
+			countRows ++;
 		}
 
 		string rowNamesD = "rownames(data) <- c("; //rowNamesDataString
 		//create rows
 		string sep2 = "";
 		for(int i=0; i < CurrentGraphData.XAxisNames.Count; i++) {
-			if(! acceptCheckedData(i))
+			//on simplesession, cols are persons. See if they are discarded on markedRows
+			if(sessions.Count == 1 && ! acceptCheckedData(i))
 				continue;
 			
 			string name = Util.RemoveTilde(CurrentGraphData.XAxisNames[i].ToString());	
@@ -996,6 +1009,11 @@ public class Stat
 				name = Util.ConvertToUnicode(name);
 
 			rowNamesD += sep2 + "'" + name  + "'";
+
+			//each four values add a \n to not have a "long line" problem in sending data to R
+			if((i+1) % 4 == 0)
+				rowNamesD += "\n";
+			
 			sep2 = ", ";
 		}
 		
