@@ -130,9 +130,15 @@ public class UtilEncoder
 				fileName = uniqueID.ToString() + "-" + personName + "-" +
 						timeStamp + ".txt";
 				
-				File.Copy(GetEncoderDataTempFileName(), 
-						GetEncoderSessionDataSignalDir(sessionID) + 
-						Path.DirectorySeparatorChar + fileName, true);
+				try {
+					File.Copy(GetEncoderDataTempFileName(), 
+							GetEncoderSessionDataSignalDir(sessionID) + 
+							Path.DirectorySeparatorChar + fileName, true);
+				} catch {
+					new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileCopyProblem);
+					Log.WriteLine(Constants.FileCopyProblem);
+					return "";
+				}
 //			}
 		}
 		return fileName;
@@ -143,9 +149,18 @@ public class UtilEncoder
 		string origin = url + Path.DirectorySeparatorChar + fileName;
 		string dest = GetEncoderDataTempFileName();
 		if(File.Exists(origin)) {
-			File.Copy(origin, dest, true);
+			try {
+				File.Copy(origin, dest, true);
+			} catch {
+				new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileCopyProblem);
+				Log.WriteLine(Constants.FileCopyProblem);
+				return false;
+			}
 			return true;
 		}
+
+		new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileNotFound);
+		Log.WriteLine(Constants.FileNotFound);
 		return false;
 	}
 	
