@@ -216,6 +216,16 @@ public class UtilGtk
 		return (val1-val2);
 	}
 	
+	public static int GetSelectedRowUniqueID (Gtk.TreeView tv, Gtk.TreeStore store, int uniqueIDcol) {
+		TreeModel model;
+		TreeIter iter1;
+
+		if (tv.Selection.GetSelected (out model, out iter1)) {
+			 return Convert.ToInt32(model.GetValue(iter1, uniqueIDcol));
+		}
+		return -1;
+	}
+
 	public static Gtk.TreeStore RemoveRow (Gtk.TreeView tv, Gtk.TreeStore store) {
 		TreeModel model;
 		TreeIter iter1;
@@ -234,6 +244,16 @@ public class UtilGtk
 		return tv;
 	}
 
+	public static void TreeviewAddRow(Gtk.TreeView tv, TreeStore store, string [] row) {
+		TreeIter iter = new TreeIter();
+		bool iterOk = store.GetIterFirst(out iter);
+			
+		iter = store.AppendValues(row);
+
+		//scroll treeview if needed
+		TreePath path = store.GetPath (iter);
+		tv.ScrollToCell (path, null, true, 0, 0);
+	}
 
 
 	/*
